# Changelog

## 0.7.2 (2026-03-17)

Full Changelog: [v0.7.1...v0.7.2](https://github.com/relax-ai/python-sdk/compare/v0.7.1...v0.7.2)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([6e49d9d](https://github.com/relax-ai/python-sdk/commit/6e49d9dd71a0b6ea8a02ce42f6f707daf2dbcac8))

## 0.7.1 (2026-03-17)

Full Changelog: [v0.7.0...v0.7.1](https://github.com/relax-ai/python-sdk/compare/v0.7.0...v0.7.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([0ee83b0](https://github.com/relax-ai/python-sdk/commit/0ee83b0f8b142d01b7ae7b09c6a6d360f32b9df5))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([2555eb2](https://github.com/relax-ai/python-sdk/commit/2555eb242461931cda6bf8998cedbdac9a4958f6))
* format all `api.md` files ([b87a725](https://github.com/relax-ai/python-sdk/commit/b87a725912d4985a25d54a1d9eac76e74b044d50))
* **internal:** add request options to SSE classes ([75229b1](https://github.com/relax-ai/python-sdk/commit/75229b14f423fb649f18e4f4b8ff5d0640ab0d01))
* **internal:** bump dependencies ([a46413f](https://github.com/relax-ai/python-sdk/commit/a46413f7f9d952c5749f0af919e4fa3c59874b2e))
* **internal:** fix lint error on Python 3.14 ([b8e6e3c](https://github.com/relax-ai/python-sdk/commit/b8e6e3c48a2cff6553f59ddeeae30f68816aa9bc))
* **internal:** make `test_proxy_environment_variables` more resilient ([b22e450](https://github.com/relax-ai/python-sdk/commit/b22e450c17a2ecb30a2ac4f15a9d13f1056ea3d6))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([f1b7477](https://github.com/relax-ai/python-sdk/commit/f1b747791c0e7c1871d9621484a8589429330f70))
* **internal:** remove mock server code ([b2cb010](https://github.com/relax-ai/python-sdk/commit/b2cb0108cf9208f528de158b707f3c9174c822f9))
* update mock server docs ([2c3c810](https://github.com/relax-ai/python-sdk/commit/2c3c8109753173e835a6284ff5e16c9d7f1a0e32))

## 0.7.0 (2026-01-30)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/relax-ai/python-sdk/compare/v0.6.0...v0.7.0)

### Features

* **client:** add custom JSON encoder for extended type support ([6b48ef2](https://github.com/relax-ai/python-sdk/commit/6b48ef2f3edb10d76d71a5ca40787f6401570577))


### Chores

* **ci:** upgrade `actions/github-script` ([cb4d9b1](https://github.com/relax-ai/python-sdk/commit/cb4d9b1854903eaed6c3197f856363b75193d1d4))
* **internal:** update `actions/checkout` version ([7ec9d4a](https://github.com/relax-ai/python-sdk/commit/7ec9d4a0b46818b7d7e5c99cce186961628ceeae))

## 0.6.0 (2026-01-14)

Full Changelog: [v0.5.9...v0.6.0](https://github.com/relax-ai/python-sdk/compare/v0.5.9...v0.6.0)

### Features

* **client:** add support for binary request streaming ([7f23ca2](https://github.com/relax-ai/python-sdk/commit/7f23ca2a03a0f1a68b81921eac0392383dc1567c))


### Chores

* **internal:** add `--fix` argument to lint script ([78355c1](https://github.com/relax-ai/python-sdk/commit/78355c1b51ee785efebdb5098edc3a4e9d2addb1))
* **internal:** codegen related update ([ecf57fd](https://github.com/relax-ai/python-sdk/commit/ecf57fd3a8196cb508d99b7fcd45e579d7e2c494))

## 0.5.9 (2025-12-18)

Full Changelog: [v0.5.8...v0.5.9](https://github.com/relax-ai/python-sdk/compare/v0.5.8...v0.5.9)

### Bug Fixes

* use async_to_httpx_files in patch method ([c0957cc](https://github.com/relax-ai/python-sdk/commit/c0957cc958e537084500d019f3cfb1452176c5ca))


### Chores

* **internal:** add missing files argument to base client ([044b2c0](https://github.com/relax-ai/python-sdk/commit/044b2c047ebf322c3545a906c7271f46d99a92d9))
* speedup initial import ([e27f67c](https://github.com/relax-ai/python-sdk/commit/e27f67c4129e01f0bada8e349d8629b67d6e611b))

## 0.5.8 (2025-12-09)

Full Changelog: [v0.5.7...v0.5.8](https://github.com/relax-ai/python-sdk/compare/v0.5.7...v0.5.8)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([3b1e638](https://github.com/relax-ai/python-sdk/commit/3b1e638578db42fa4c711bfe9c3af0fb8139211d))


### Chores

* **docs:** use environment variables for authentication in code snippets ([f7d77ea](https://github.com/relax-ai/python-sdk/commit/f7d77eaa9e69e2a635d275023db22fed2320e97d))
* update lockfile ([3b2d5e1](https://github.com/relax-ai/python-sdk/commit/3b2d5e122b3f408d8622bdb99cccd927f4f690e4))

## 0.5.7 (2025-11-28)

Full Changelog: [v0.5.6...v0.5.7](https://github.com/relax-ai/python-sdk/compare/v0.5.6...v0.5.7)

### Bug Fixes

* ensure streams are always closed ([d1005fe](https://github.com/relax-ai/python-sdk/commit/d1005feade9cfdfc835c348f4582a16bf2e3b3fb))


### Chores

* add Python 3.14 classifier and testing ([e46160a](https://github.com/relax-ai/python-sdk/commit/e46160aae10727e4bf3a5b770e89d1c00925cb73))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([b965ed4](https://github.com/relax-ai/python-sdk/commit/b965ed40749821862ee70fa58708b6defa911c0a))

## 0.5.6 (2025-11-12)

Full Changelog: [v0.5.5...v0.5.6](https://github.com/relax-ai/python-sdk/compare/v0.5.5...v0.5.6)

### Bug Fixes

* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([191b48d](https://github.com/relax-ai/python-sdk/commit/191b48de2f9b510ad819ba3a62feb9e08470ea25))

## 0.5.5 (2025-11-11)

Full Changelog: [v0.5.4...v0.5.5](https://github.com/relax-ai/python-sdk/compare/v0.5.4...v0.5.5)

### Bug Fixes

* compat with Python 3.14 ([a46573f](https://github.com/relax-ai/python-sdk/commit/a46573f92d95e656694b00a50a12afc0fb4a1921))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([c9452e7](https://github.com/relax-ai/python-sdk/commit/c9452e7838f9d19e5e0a1d386731d46b8b88befb))
* **internal:** grammar fix (it's -&gt; its) ([023f937](https://github.com/relax-ai/python-sdk/commit/023f93735bce1f67cd92e2db714c71ca95ecea9c))
* **package:** drop Python 3.8 support ([aa34fcd](https://github.com/relax-ai/python-sdk/commit/aa34fcd579bcfc00d0d40ede2de98d97287a9f28))

## 0.5.4 (2025-10-30)

Full Changelog: [v0.5.3...v0.5.4](https://github.com/relax-ai/python-sdk/compare/v0.5.3...v0.5.4)

### Bug Fixes

* **client:** close streams without requiring full consumption ([f1585d4](https://github.com/relax-ai/python-sdk/commit/f1585d485b103ca4729480ef8ff70869dc2023fa))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([aa4e07a](https://github.com/relax-ai/python-sdk/commit/aa4e07a80e794bd468441a9a74b49db95fa6aa48))

## 0.5.3 (2025-10-15)

Full Changelog: [v0.5.2...v0.5.3](https://github.com/relax-ai/python-sdk/compare/v0.5.2...v0.5.3)

### Bug Fixes

* **api:** add timeout to deepresearch ([3da40a5](https://github.com/relax-ai/python-sdk/commit/3da40a5123bdd6608b0510a3d0e94e5356b2e5fa))

## 0.5.2 (2025-10-15)

Full Changelog: [v0.5.1...v0.5.2](https://github.com/relax-ai/python-sdk/compare/v0.5.1...v0.5.2)

### Bug Fixes

* **api:** Change 200 response format ([01fa29f](https://github.com/relax-ai/python-sdk/commit/01fa29ff96f513a6d0e03ecc65b361f5a0f115fd))

## 0.5.1 (2025-10-15)

Full Changelog: [v0.5.0...v0.5.1](https://github.com/relax-ai/python-sdk/compare/v0.5.0...v0.5.1)

### Bug Fixes

* **api:** Readme Updates ([7c6e100](https://github.com/relax-ai/python-sdk/commit/7c6e100014267ec4f3633a6ba16431c1a3378027))

## 0.5.0 (2025-10-15)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/relax-ai/python-sdk/compare/v0.4.0...v0.5.0)

### Features

* **api:** manual updates ([3fc9bea](https://github.com/relax-ai/python-sdk/commit/3fc9bea27a11c3321fa54b1531c3b9da228a01d7))

## 0.4.0 (2025-10-15)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/relax-ai/python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([b504578](https://github.com/relax-ai/python-sdk/commit/b504578cf1454d571cb19321767878c21b8b27fd))

## 0.3.0 (2025-10-15)

Full Changelog: [v0.2.1...v0.3.0](https://github.com/relax-ai/python-sdk/compare/v0.2.1...v0.3.0)

### Features

* **api:** manual updates ([fb55fbb](https://github.com/relax-ai/python-sdk/commit/fb55fbbad43d0e9e451cd478fdc245c13ac902d5))
* **api:** manual updates ([01862ef](https://github.com/relax-ai/python-sdk/commit/01862efe3dbab403d0b375368dfc1abe7da8c207))
* **api:** manual updates ([a87f00a](https://github.com/relax-ai/python-sdk/commit/a87f00af92db246737d129211b1288624cc968fd))
* improve future compat with pydantic v3 ([e6f68a5](https://github.com/relax-ai/python-sdk/commit/e6f68a526ac50b2a439770d778e1f7bf024614e2))
* **types:** replace List[str] with SequenceNotStr in params ([151f372](https://github.com/relax-ai/python-sdk/commit/151f372fe9393e0a4d6e276a0590608730c7db31))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([4e5f72f](https://github.com/relax-ai/python-sdk/commit/4e5f72f42aa9931746d4883dc8fdcc0c458d5696))
* **internal:** add Sequence related utils ([d2984db](https://github.com/relax-ai/python-sdk/commit/d2984db3cfd795659892617f88bc36e77f69d379))
* **internal:** detect missing future annotations with ruff ([826ae50](https://github.com/relax-ai/python-sdk/commit/826ae504f63ac7182e4420547b83003e7d7edc34))
* **internal:** move mypy configurations to `pyproject.toml` file ([466a932](https://github.com/relax-ai/python-sdk/commit/466a932633583de1e75b3d2574fd189c4997637e))
* **internal:** update pydantic dependency ([453c07f](https://github.com/relax-ai/python-sdk/commit/453c07f92fa1f2a54c0d80b282d3404199d8e455))
* **internal:** update pyright exclude list ([b38f5fa](https://github.com/relax-ai/python-sdk/commit/b38f5fafdf9a2ae1ce03e5750472582000289bc8))
* **tests:** simplify `get_platform` test ([9c5443b](https://github.com/relax-ai/python-sdk/commit/9c5443be195c8eb14a40c211fe4ce25c4a701113))
* **types:** change optional parameter type from NotGiven to Omit ([9fc9e2f](https://github.com/relax-ai/python-sdk/commit/9fc9e2fa695f30d157d2bae209b41ae2204076bb))

## 0.2.1 (2025-08-27)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/relax-ai/python-sdk/compare/v0.2.0...v0.2.1)

### Bug Fixes

* avoid newer type syntax ([865829c](https://github.com/relax-ai/python-sdk/commit/865829ccb7f5e55542e935ff364f25481a57f27b))

## 0.2.0 (2025-08-26)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/relax-ai/python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** update via SDK Studio ([b6b872a](https://github.com/relax-ai/python-sdk/commit/b6b872a587317b3beabc763b184efce32540ab99))
* **api:** update via SDK Studio ([964dabf](https://github.com/relax-ai/python-sdk/commit/964dabfcf0d2f2f9ad50edfa2d3e10f0eb734ffa))
* **api:** update via SDK Studio ([4a14a81](https://github.com/relax-ai/python-sdk/commit/4a14a8195f4881739c7e6cc12a2fb2e7606710f0))
* **api:** update via SDK Studio ([51c08b4](https://github.com/relax-ai/python-sdk/commit/51c08b4f2d5e5126d8dc8c2eec3ef8147b30fef6))
* **api:** update via SDK Studio ([d06b5d0](https://github.com/relax-ai/python-sdk/commit/d06b5d097de5a937d0d2092fbbc2a4bed4bab05e))
* **api:** update via SDK Studio ([2d5a57d](https://github.com/relax-ai/python-sdk/commit/2d5a57dbb738972bce08a682c4fc2e98af372309))
* **api:** update via SDK Studio ([2f09580](https://github.com/relax-ai/python-sdk/commit/2f0958064f86668d55ed4dea2c6a21ecaf6b791c))
* **api:** update via SDK Studio ([6430e6f](https://github.com/relax-ai/python-sdk/commit/6430e6f00de2de2b0c95277d456e7937226d6e4f))
* **api:** update via SDK Studio ([11aae68](https://github.com/relax-ai/python-sdk/commit/11aae68a730b918abf5d9c8f0991ca923d15a5d7))
* **api:** update via SDK Studio ([53fd3c1](https://github.com/relax-ai/python-sdk/commit/53fd3c18d19447b5a2314af8c2626dcc83ab6176))
* clean up environment call outs ([fd52000](https://github.com/relax-ai/python-sdk/commit/fd52000dd6823e3f52759ffb32457b1b6bb777e8))
* **client:** support file upload requests ([e70c0ec](https://github.com/relax-ai/python-sdk/commit/e70c0ecbd97586746fcaa4618f8c7c254fe5edbb))


### Bug Fixes

* **ci:** correct conditional ([7b9dd73](https://github.com/relax-ai/python-sdk/commit/7b9dd73dec12d098f3908c46804fea6323991933))
* **client:** don't send Content-Type header on GET requests ([134d444](https://github.com/relax-ai/python-sdk/commit/134d444d1e46fa968b03c1d2c29a81a3f50260bc))
* **parsing:** correctly handle nested discriminated unions ([f3f2481](https://github.com/relax-ai/python-sdk/commit/f3f2481e3b294c4859dce817620beeda0750df70))
* **parsing:** ignore empty metadata ([5a69522](https://github.com/relax-ai/python-sdk/commit/5a695221f0607e7140856e41cc84057fed534cf5))
* **parsing:** parse extra field types ([058ebec](https://github.com/relax-ai/python-sdk/commit/058ebec52bdfbdd0fa5d094507ec0151954d7611))


### Chores

* **ci:** change upload type ([d0eac9e](https://github.com/relax-ai/python-sdk/commit/d0eac9e1c21f5af782d7b6b0e9d4e12a7ae1ba4b))
* **ci:** only run for pushes and fork pull requests ([2823330](https://github.com/relax-ai/python-sdk/commit/28233300e18b343582f000c7809c6d5f9e5c9dfd))
* **internal:** bump pinned h11 dep ([2fcd331](https://github.com/relax-ai/python-sdk/commit/2fcd331182be60fe3186a12bf076c0792312d340))
* **internal:** change ci workflow machines ([9674302](https://github.com/relax-ai/python-sdk/commit/96743023d78761ffb5f52f6d50a8ae66ca1df896))
* **internal:** codegen related update ([cf132b1](https://github.com/relax-ai/python-sdk/commit/cf132b191e08d91e189d3dd910f020121511ec4b))
* **internal:** fix ruff target version ([98ebba8](https://github.com/relax-ai/python-sdk/commit/98ebba829120bb69d9c97a8c434748ee216427c4))
* **internal:** version bump ([0a019aa](https://github.com/relax-ai/python-sdk/commit/0a019aa4888b574cc3892e8a1ed188330c97f971))
* **package:** mark python 3.13 as supported ([75f9e16](https://github.com/relax-ai/python-sdk/commit/75f9e16cf24b3ce117503d87083ef95511230c95))
* **project:** add settings file for vscode ([d91c008](https://github.com/relax-ai/python-sdk/commit/d91c008238bb40bfe103413b61798695821f2e66))
* **readme:** fix version rendering on pypi ([ba4beb8](https://github.com/relax-ai/python-sdk/commit/ba4beb8326b69e8dc5e54e014620c35681e21114))
* sync repo ([0bb5fc8](https://github.com/relax-ai/python-sdk/commit/0bb5fc82969d958f999c864a47af4b95be8f41cf))
* update @stainless-api/prism-cli to v5.15.0 ([5e5155e](https://github.com/relax-ai/python-sdk/commit/5e5155e471ec22bd51e51c08272fef2281e9c523))
* update github action ([fa9264e](https://github.com/relax-ai/python-sdk/commit/fa9264e1d1436107e76924ba4e233268f53e8751))
* update SDK settings ([682ca85](https://github.com/relax-ai/python-sdk/commit/682ca85bbaf7b9ed51f01f9c2090db8dc7890ce3))
* update SDK settings ([b6c7f5a](https://github.com/relax-ai/python-sdk/commit/b6c7f5aebefb986948527773a67b92fe2fb15954))
* update SDK settings ([fc9f194](https://github.com/relax-ai/python-sdk/commit/fc9f194e0d241fb70577baba8285b31f76677d19))

## 0.18.0 (2025-08-26)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/relax-ai/python-sdk/compare/v0.17.0...v0.18.0)

### Features

* **api:** update via SDK Studio ([84e3923](https://github.com/relax-ai/python-sdk/commit/84e39231319fec115847186246f58c9d95cc6095))

## 0.17.0 (2025-08-26)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/relax-ai/python-sdk/compare/v0.16.0...v0.17.0)

### Features

* **api:** update via SDK Studio ([e8708e9](https://github.com/relax-ai/python-sdk/commit/e8708e99ebb76318a9009606471bfbfb8f762ac4))

## 0.16.0 (2025-08-26)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/relax-ai/python-sdk/compare/v0.15.0...v0.16.0)

### Features

* **api:** update via SDK Studio ([cdf054a](https://github.com/relax-ai/python-sdk/commit/cdf054a861f447ef6cdb26af3b93d99e34aac307))
* **api:** update via SDK Studio ([f6ed73b](https://github.com/relax-ai/python-sdk/commit/f6ed73b46ba3716a4d7fda707d9dcc6acb1e962b))

## 0.15.0 (2025-08-26)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/relax-ai/python-sdk/compare/v0.14.0...v0.15.0)

### Features

* **api:** update via SDK Studio ([978b8c1](https://github.com/relax-ai/python-sdk/commit/978b8c14f5b522c5c2301ffb7b13ead2640773f1))

## 0.14.0 (2025-08-26)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/relax-ai/python-sdk/compare/v0.13.0...v0.14.0)

### Features

* **api:** update via SDK Studio ([8908751](https://github.com/relax-ai/python-sdk/commit/8908751c9870e75139a00ce8a49578450b805941))
* **api:** update via SDK Studio ([14ec145](https://github.com/relax-ai/python-sdk/commit/14ec145db8a0ab1360fb3a085ca489d9ca8afeb1))

## 0.13.0 (2025-08-26)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/relax-ai/python-sdk/compare/v0.12.0...v0.13.0)

### Features

* **api:** update via SDK Studio ([92fe5ae](https://github.com/relax-ai/python-sdk/commit/92fe5ae1ced1942f524f4233f7be7413b044b264))


### Chores

* **internal:** change ci workflow machines ([4f8c965](https://github.com/relax-ai/python-sdk/commit/4f8c9652a55ebefcd7a7a034a2eebeedba13f2cb))
* update github action ([82bdf02](https://github.com/relax-ai/python-sdk/commit/82bdf0209421625e4d4d01b371784b1e98c97d62))

## 0.12.0 (2025-08-21)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/relax-ai/python-sdk/compare/v0.11.0...v0.12.0)

### Features

* **api:** update via SDK Studio ([11aae68](https://github.com/relax-ai/python-sdk/commit/11aae68a730b918abf5d9c8f0991ca923d15a5d7))
* **api:** update via SDK Studio ([53fd3c1](https://github.com/relax-ai/python-sdk/commit/53fd3c18d19447b5a2314af8c2626dcc83ab6176))
* clean up environment call outs ([fd52000](https://github.com/relax-ai/python-sdk/commit/fd52000dd6823e3f52759ffb32457b1b6bb777e8))
* **client:** support file upload requests ([e70c0ec](https://github.com/relax-ai/python-sdk/commit/e70c0ecbd97586746fcaa4618f8c7c254fe5edbb))


### Bug Fixes

* **ci:** correct conditional ([7b9dd73](https://github.com/relax-ai/python-sdk/commit/7b9dd73dec12d098f3908c46804fea6323991933))
* **client:** don't send Content-Type header on GET requests ([134d444](https://github.com/relax-ai/python-sdk/commit/134d444d1e46fa968b03c1d2c29a81a3f50260bc))
* **parsing:** correctly handle nested discriminated unions ([f3f2481](https://github.com/relax-ai/python-sdk/commit/f3f2481e3b294c4859dce817620beeda0750df70))
* **parsing:** ignore empty metadata ([5a69522](https://github.com/relax-ai/python-sdk/commit/5a695221f0607e7140856e41cc84057fed534cf5))
* **parsing:** parse extra field types ([058ebec](https://github.com/relax-ai/python-sdk/commit/058ebec52bdfbdd0fa5d094507ec0151954d7611))


### Chores

* **ci:** change upload type ([d0eac9e](https://github.com/relax-ai/python-sdk/commit/d0eac9e1c21f5af782d7b6b0e9d4e12a7ae1ba4b))
* **ci:** only run for pushes and fork pull requests ([2823330](https://github.com/relax-ai/python-sdk/commit/28233300e18b343582f000c7809c6d5f9e5c9dfd))
* **internal:** bump pinned h11 dep ([2fcd331](https://github.com/relax-ai/python-sdk/commit/2fcd331182be60fe3186a12bf076c0792312d340))
* **internal:** codegen related update ([cf132b1](https://github.com/relax-ai/python-sdk/commit/cf132b191e08d91e189d3dd910f020121511ec4b))
* **internal:** fix ruff target version ([98ebba8](https://github.com/relax-ai/python-sdk/commit/98ebba829120bb69d9c97a8c434748ee216427c4))
* **internal:** version bump ([0a019aa](https://github.com/relax-ai/python-sdk/commit/0a019aa4888b574cc3892e8a1ed188330c97f971))
* **package:** mark python 3.13 as supported ([75f9e16](https://github.com/relax-ai/python-sdk/commit/75f9e16cf24b3ce117503d87083ef95511230c95))
* **project:** add settings file for vscode ([d91c008](https://github.com/relax-ai/python-sdk/commit/d91c008238bb40bfe103413b61798695821f2e66))
* **readme:** fix version rendering on pypi ([ba4beb8](https://github.com/relax-ai/python-sdk/commit/ba4beb8326b69e8dc5e54e014620c35681e21114))
* sync repo ([0bb5fc8](https://github.com/relax-ai/python-sdk/commit/0bb5fc82969d958f999c864a47af4b95be8f41cf))
* update @stainless-api/prism-cli to v5.15.0 ([5e5155e](https://github.com/relax-ai/python-sdk/commit/5e5155e471ec22bd51e51c08272fef2281e9c523))
* update SDK settings ([682ca85](https://github.com/relax-ai/python-sdk/commit/682ca85bbaf7b9ed51f01f9c2090db8dc7890ce3))
* update SDK settings ([b6c7f5a](https://github.com/relax-ai/python-sdk/commit/b6c7f5aebefb986948527773a67b92fe2fb15954))
* update SDK settings ([fc9f194](https://github.com/relax-ai/python-sdk/commit/fc9f194e0d241fb70577baba8285b31f76677d19))

## 0.11.0 (2025-08-20)

Full Changelog: [v0.1.0...v0.11.0](https://github.com/bennorris123/python-sdk-test/compare/v0.1.0...v0.11.0)

### Chores

* sync repo ([8b4f938](https://github.com/bennorris123/python-sdk-test/commit/8b4f93863d6771931ceaa4441a43e4fd45300804))
* update SDK settings ([5e557e4](https://github.com/bennorris123/python-sdk-test/commit/5e557e44d1f50b8f26e94253d9ab6e0bf2941689))
* update SDK settings ([1d0944d](https://github.com/bennorris123/python-sdk-test/commit/1d0944db459fd31e320413b82ad110dcc7c52bd3))

## 0.1.0 (2025-07-25)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/relax-ai/python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** update via SDK Studio ([53fd3c1](https://github.com/relax-ai/python-sdk/commit/53fd3c18d19447b5a2314af8c2626dcc83ab6176))
* clean up environment call outs ([fd52000](https://github.com/relax-ai/python-sdk/commit/fd52000dd6823e3f52759ffb32457b1b6bb777e8))


### Bug Fixes

* **ci:** correct conditional ([7b9dd73](https://github.com/relax-ai/python-sdk/commit/7b9dd73dec12d098f3908c46804fea6323991933))
* **client:** don't send Content-Type header on GET requests ([134d444](https://github.com/relax-ai/python-sdk/commit/134d444d1e46fa968b03c1d2c29a81a3f50260bc))
* **parsing:** correctly handle nested discriminated unions ([f3f2481](https://github.com/relax-ai/python-sdk/commit/f3f2481e3b294c4859dce817620beeda0750df70))
* **parsing:** ignore empty metadata ([5a69522](https://github.com/relax-ai/python-sdk/commit/5a695221f0607e7140856e41cc84057fed534cf5))
* **parsing:** parse extra field types ([058ebec](https://github.com/relax-ai/python-sdk/commit/058ebec52bdfbdd0fa5d094507ec0151954d7611))


### Chores

* **ci:** change upload type ([d0eac9e](https://github.com/relax-ai/python-sdk/commit/d0eac9e1c21f5af782d7b6b0e9d4e12a7ae1ba4b))
* **ci:** only run for pushes and fork pull requests ([2823330](https://github.com/relax-ai/python-sdk/commit/28233300e18b343582f000c7809c6d5f9e5c9dfd))
* **internal:** bump pinned h11 dep ([2fcd331](https://github.com/relax-ai/python-sdk/commit/2fcd331182be60fe3186a12bf076c0792312d340))
* **internal:** codegen related update ([cf132b1](https://github.com/relax-ai/python-sdk/commit/cf132b191e08d91e189d3dd910f020121511ec4b))
* **internal:** version bump ([0a019aa](https://github.com/relax-ai/python-sdk/commit/0a019aa4888b574cc3892e8a1ed188330c97f971))
* **package:** mark python 3.13 as supported ([75f9e16](https://github.com/relax-ai/python-sdk/commit/75f9e16cf24b3ce117503d87083ef95511230c95))
* **project:** add settings file for vscode ([d91c008](https://github.com/relax-ai/python-sdk/commit/d91c008238bb40bfe103413b61798695821f2e66))
* **readme:** fix version rendering on pypi ([ba4beb8](https://github.com/relax-ai/python-sdk/commit/ba4beb8326b69e8dc5e54e014620c35681e21114))

## 0.0.1 (2025-06-27)

Full Changelog: [v0.0.1-alpha.0...v0.0.1](https://github.com/relax-ai/python-sdk/compare/v0.0.1-alpha.0...v0.0.1)

### Chores

* update SDK settings ([b6c7f5a](https://github.com/relax-ai/python-sdk/commit/b6c7f5aebefb986948527773a67b92fe2fb15954))
* update SDK settings ([fc9f194](https://github.com/relax-ai/python-sdk/commit/fc9f194e0d241fb70577baba8285b31f76677d19))
